package bus_apis

import (
	"github.com/gin-gonic/gin"
	"github.com/go-admin-team/go-admin-core/logger"
	"github.com/go-admin-team/go-admin-core/sdk/api"
	"go-admin/app/admin/models/bus_models"
	aliyun "go-admin/tools/ali"
	"go-admin/tools/app"
)

type CommonApi struct {
	api.Api
}

// AliYunStsTokenGet 获取阿里云oss对象存储token
// @Summary 获取阿里云oss对象存储token
// @Tags 公共模块-V1.0.0
// @Produce json
// @Accept json
// @Success 200 {object} bus_models.RspAliyunStsToken
// @Router /api/v1/common/aliyun/sts_token [post]
func (e CommonApi) AliYunStsTokenGet(c *gin.Context) {
	uploadInfo, err := aliyun.GenStsToken("21000505")
	if err != nil {
		logger.Error("aliyun.GenStsToken err", err)
		return
	}

	stsToken := bus_models.RspAliyunStsToken{
		AccessKeyId:     uploadInfo.AccessKeyId,
		AccessKeySecret: uploadInfo.AccessKeySecret,
		SecurityToken:   uploadInfo.SecurityToken,
		BucketName:      uploadInfo.BucketName,
		Expiration:      uint64(uploadInfo.Expiration),
	}

	ret := map[string]interface{}{
		"stsToken": stsToken,
		"ossUrl":   aliyun.AliyunOssUrl,
	}
	app.OK(c, ret, "")
	return
}
